-- Class: Julia Set
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 11/01/2012
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Notes: Calculates a Julia set based on parameters
--

local JuliaSet = {}
local JuliaSet_mt = {__index = JuliaSet}

function JuliaSet.new(params)
	local class = {
	}
	
	return setmetatable(class, JuliaSet_mt)
end

function JuliaSet:calculateSet(params)
	local realAxisMinimum = params.realAxisMinimum
	local realAxisMaximum = params.realAxisMaximum
	local imaginaryAxisMinimum = params.imaginaryAxisMinimum
	local imaginaryAxisMaximum = params.imaginaryAxisMaximum
	local seedRealValue = params.seedRealValue
	local seedImaginaryValue = params.seedImaginaryValue
	local maxIterations = params.maxIterations

	local outputWidth = params.outputWidth
	local outputHeight = params.outputHeight

	-- initialise output
	local outputSet = {}
	for y = 0, outputHeight do
		local row = {}
		for x = 0, outputWidth do
			row[x] = 0
		end
		outputSet[y] = row
	end


	local xStep = (realAxisMaximum - realAxisMinimum) / outputWidth
	local yStep = (imaginaryAxisMaximum - imaginaryAxisMinimum) / outputHeight

	local currentIteration = 0
	local startX = realAxisMinimum
	local startY = imaginaryAxisMinimum
	local pathX = 0
	local pathY = 0
	local tempPathX = 0
	local tempPathY = 0

	for y = 0, outputHeight - 1 do
		startX = realAxisMinimum

		for x = 0, outputWidth - 1 do
			currentIteration = 0
			pathX = startX
			pathY = startY

			while ( (pathX*pathX + pathY*pathY) < 4 and currentIteration < maxIterations) do
				tempPathX = pathX*pathX - pathY*pathY + seedRealValue
				tempPathY = 2*pathX*pathY + seedImaginaryValue

				currentIteration = currentIteration + 1

				pathX = tempPathX
				pathY = tempPathY					
			end

			outputSet[y][x] = currentIteration

			startX = startX + xStep
		end

		startY = startY + yStep
	end

	self.outputSet = outputSet
end

function JuliaSet:getSet()
	return self.outputSet
end


return JuliaSet