-- Class: Mandelbrot Set
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 11/01/2012
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Notes: Calculates a mandelbrot set based on parameters
--

local MandelbrotSet = {}
local MandelbrotSet_mt = {__index = MandelbrotSet}

function MandelbrotSet.new(params)
	local class = {
	}
	
	return setmetatable(class, MandelbrotSet_mt)
end

function MandelbrotSet:calculateSet(params)
	local realAxisMinimum = params.realAxisMinimum
	local realAxisMaximum = params.realAxisMaximum
	local imaginaryAxisMinimum = params.imaginaryAxisMinimum
	local imaginaryAxisMaximum = params.imaginaryAxisMaximum
	local maxIterations = params.maxIterations

	local outputWidth = params.outputWidth
	local outputHeight = params.outputHeight
	
	-- initialise output
	local outputSet = {}
	for y = 0, outputHeight do
		local row = {}
		for x = 0, outputWidth do
			row[x] = 0
		end
		outputSet[y] = row
	end
		
	local xStep = (realAxisMaximum - realAxisMinimum) / outputWidth
	local yStep = (imaginaryAxisMaximum - imaginaryAxisMinimum) / outputHeight

	local currentIteration = 0
	local startX = realAxisMinimum
	local startY = imaginaryAxisMinimum
	local pathX = 0
	local pathY = 0
	local tempPathX = 0
	local tempPathY = 0

	for y = 0, outputHeight - 1 do
		startX = realAxisMinimum

		for x = 0, outputWidth - 1 do
			currentIteration = 0
			pathX = 0
			pathY = 0

			while ( ((pathX*pathX + pathY*pathY) < 4) and currentIteration < maxIterations) do
				tempPathX = pathX*pathX - pathY*pathY + startX
				tempPathY = 2*pathX*pathY + startY

				currentIteration = currentIteration + 1

				pathX = tempPathX
				pathY = tempPathY					
			end

			outputSet[y][x] = currentIteration

			startX = startX + xStep
		end

		startY = startY + yStep
	end
	
	self.outputSet = outputSet
end

function MandelbrotSet:getSet()
	return self.outputSet
end


return MandelbrotSet