-- Class: Renderer
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 11/01/2012
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Notes: Custom render class for mandelbrot and julia sets
--

local Renderer = {}
local Renderer_mt = {__index = Renderer}

function Renderer.new(params)
	local displayGroup = display.newGroup()
	
	local class = {
		displayGroup = displayGroup,
	}
	
	return setmetatable(class, Renderer_mt)
end

function Renderer:initialise(params)
	local displayGroup = self.displayGroup
	
	local outputWidth = params.outputWidth
	local outputHeight = params.outputHeight
	local cellWidth = params.cellWidth
	local cellHeight = params.cellHeight
	
	local displayCells = {}
	
	local top = 0
	for y = 0, outputHeight - 1 do
		local row = {}
		local left = 0
		
		for x = 0, outputWidth - 1 do
			local newCell = display.newRect(displayGroup, left, top, cellWidth, cellHeight)
			newCell:setFillColor(0, 0, 0)
			
			row[x] = newCell
			
			left = left + cellWidth
		end
		
		displayCells[y] = row
		top = top + cellHeight
	end
	
	self.outputHeight = outputHeight
	self.outputWidth = outputWidth
	self.displayCells = displayCells	
end

function Renderer:setRenderSet(renderSet)
	local displayCells = self.displayCells
	local outputHeight = self.outputHeight
	local outputWidth = self.outputWidth
	
	for y = 0, outputHeight - 1 do
		for x = 0, outputWidth - 1 do
			local cell = displayCells[y][x]
			local intensity = renderSet[y][x]
			local shade = intensity
			
			cell:setFillColor(shade, shade, shade)
		end
	end
	
	self.renderSet = renderSet
end

return Renderer